summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmmeshedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmmeshedit.h')
-rw-r--r--kpovmodeler/pmmeshedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmmeshedit.h b/kpovmodeler/pmmeshedit.h
index e9d71054..83b9d161 100644
--- a/kpovmodeler/pmmeshedit.h
+++ b/kpovmodeler/pmmeshedit.h
@@ -40,9 +40,9 @@ class PMMeshEdit : public PMSolidObjectEdit
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMMeshEdit with tqparent and name
*/
- PMMeshEdit( TQWidget* tqparent, const char* name = 0 );
+ PMMeshEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -40,9 +40,9 @@ class PMMeshEdit : public PMSolidObjectEdit
public:
/**
- * Creates a PMMeshEdit with tqparent and name
+ * Creates a PMMeshEdit with parent and name
*/